@@ -5,32 +5,10 @@
 
 <br>
 
-# How it works
+# [User manual](docs_user_manual/index.html)
 
-.. image:: resources/flow.png
+# [Developer manual](docs_developer_manual/index.html)
 
-# Pattern specifications
-
-Browse [spec.md](https://github.com/laowantong/paroxython/blob/master/paroxython/resources/spec.md) on GitHub.
-
-# Default Taxonomy
-
-Browse [taxonomy.tsv](https://github.com/laowantong/paroxython/blob/master/paroxython/resources/taxonomy.tsv) on GitHub.
-
-# User types
-
-Paroxython makes heavy use of Python 3.5+ [type hints](https://docs.python.org/3/library/typing.html).
-They are documented directly in the source code.
-Browse [user_types.py](https://github.com/laowantong/paroxython/blob/master/paroxython/user_types.py) on GitHub.
-
-# Glossary
-
-- Hint:
-- Label:
-- Span:
-- Tag:
-- Taxon:
-- Taxonomy:
 """
 
 
@@ -49,10 +27,11 @@ if "ipykernel" in sys.modules:
 
     @magics_class
     class ParoxythonMagics(Magics):
+        @staticmethod
         @line_cell_magic
         def paroxython(self, line, source=None):
             """
-            Tag a Python code cell and output the table of its taxons or labels.
+            Tag a Python code cell and output the table of its taxa or labels.
 
             In cell mode:
                 %%paroxython [labels] [raw]
