@@ -1,10 +1,10 @@
 r"""Assess the learning cost associated with the introduction of the given programs.
 
 Each program has been previously found to implement a number of notions represented by a list of
-taxons of the form: \(\textrm{edge}_0/\textrm{edge}_1/.../\textrm{edge}_n\), e.g.,
+taxa of the form: \(\textrm{edge}_0/\textrm{edge}_1/.../\textrm{edge}_n\), _e.g._,
 `flow/loop/exit/early/break`.
 
-Furthermore, the notions already imparted may cover a certain **prefix** of such a taxon, e.g.
+Furthermore, the notions already imparted may cover a certain **prefix** of such a taxon, _e.g._
 `flow/loop`. The learning cost should therefore not take it into account.
 
 The cost of the remaining edges, here `exit/early/break`, is approximated by a function taking
@@ -20,18 +20,22 @@ from functools import lru_cache
 from .user_types import (
     AssessedPrograms,
     AssessmentStrategy,
-    ProgramTaxonNames,
+    ProgramInfos,
+    ProgramNameSet,
     TaxonName,
     TaxonNameSet,
 )
 
-__pdoc__ = {"LearningCostAssessor.__call__": True}
+__pdoc__ = {
+    "LearningCostAssessor.__call__": True,
+    "LearningCostAssessor.__init__": True,
+    "LearningCostAssessor": "",
+}
 
 
 @lru_cache(maxsize=None)  # NB: memoization needed for consistency with mypy's typing
 def range_to_cost_linear(start: int, stop: int) -> float:
-    """Return the length of the slice between `start` (inclusive) and `stop` (exclusive).
-    """
+    """Return the length of the slice between `start` (inclusive) and `stop` (exclusive)."""
     return float(stop - start)
 
 
@@ -60,36 +64,33 @@ def range_to_cost_zeno(start: int, stop: int) -> float:
 
 
 class LearningCostAssessor:
-    def __init__(self, imparted_knowledge: TaxonNameSet) -> None:
-        """Evaluate the learning costs of programs with respect to the given imparted knowledge.
+    """Evaluate the learning costs of programs with respect to the given imparted knowledge."""
+
+    def __init__(self, programs: ProgramInfos, assessment_strategy: AssessmentStrategy = "zeno"):
+        """Set the programs and the function to be used for the learning cost calculation.
 
         Args:
-            imparted_knowledge (TaxonNameSet): A set of taxon names, representing all the notions
-                introduced so far.
-        """
-        self.imparted_knowledge = imparted_knowledge
-
-    def set_cost_assessment_strategy(self, strategy: AssessmentStrategy = "zeno") -> None:
-        """Set the function to be used for the learning cost calculation.
-
-        Args:
-            strategy (str, optional): Either:
+            assessment_strategy (str, optional): Either:
 
                 - `"zeno"`: `range_to_cost_zeno` (default).
                 - `"linear"`: `range_to_cost_linear`.
 
         Raises:
-            NotImplementedError: Raised in case of unknown strategy.
+            NotImplementedError: Raised in case of unknown assessment_strategy.
         """
-        if strategy.lower() == "zeno":
+        self.programs = programs
+        if assessment_strategy.lower() == "zeno":
             self.range_to_cost = range_to_cost_zeno
-        elif strategy == "linear":
+        elif assessment_strategy == "linear":
             self.range_to_cost = range_to_cost_linear
         else:
             raise NotImplementedError
         self.range_to_cost.cache_clear()
         self.taxon_cost.cache_clear()
 
+    def set_imparted_knowledge(self, imparted_knowledge: TaxonNameSet) -> None:
+        self.imparted_knowledge = imparted_knowledge
+
     @lru_cache(maxsize=None)
     def taxon_cost(self, taxon: TaxonName) -> float:
         """Evaluate the learning cost of a given taxon.
@@ -111,20 +112,19 @@ class LearningCostAssessor:
                     break
         return self.range_to_cost(start, stop)
 
-    def __call__(self, programs: ProgramTaxonNames) -> AssessedPrograms:
-        """Associate the given programs with the total learning cost of their taxons.
+    def __call__(self, selected_programs: ProgramNameSet) -> AssessedPrograms:
+        """Associate the given selected programs with the total learning cost of their taxa.
 
         Args:
-            programs (ProgramTaxonNames): A dictionary associating each program name with a list
-                of taxon names.
+            selected_programs (ProgramNameSet): A set of program names.
 
         Returns:
             AssessedPrograms: A list of tuples `(total_cost, ProgramName)` sorted by increasing cost.
         """
         result = []
-        for (program_name, taxon_names) in programs.items():
+        for program_name in selected_programs:
             total_cost = 0.0
-            for taxon_name in taxon_names:
+            for taxon_name in self.programs[program_name]["taxa"]:
                 total_cost += self.taxon_cost(taxon_name)
             result.append((total_cost, program_name))
         return sorted(result)
