@@ -1,16 +1,20 @@
-r"""
+r"""Walk a directory, tag its Python files and make a database of the results.
+
 USAGE:
+    ```
     paroxython collect [options] DIRECTORY
+    ```
 
 OPTIONS:
+    ```plain
     -c --cleanup=STR    Transformation to be applied to the source code
                         before processing. [default: full]
                         Currently available:
                         • full: remove all blank lines, docstrings and
                                 comments (except Paroxython hints).
                         • none: no transformation is applied.
-    -e --exclude=REGEX  Filter out any file whose name fully matches this
-                        regular expression. NB: --glob precedes --exclude.
+    -e --skip=REGEX     Filter out any file whose name fully matches this
+                        regular expression. NB: --glob precedes --skip.
                         [default: "^(__init__|setup|.*[-_]tests?)\.py$"]
     -g --glob=PATTERN   The names of the collected files must match this
                         Unix-like glob pattern (not a regular expression).
@@ -22,12 +26,11 @@ OPTIONS:
                         "DIRECTORY_db.json". Otherwise, use the extension
                         (either ".json" or ".sqlite") to decide the format
                         of the database. [default: ]
-    -t --taxonomy=PATH  The path of a TSV file mapping labels onto taxons.
-                        If not specified, use the included copy of the table
-                        whose last version is at https://bit.ly/2Yu0LqU.
-
-DESCRIPTION:
-    Walk a directory, tag its Python files and make a database of the results.
+    --no_timestamp      Don't store programs' last modification date.
+    -t --taxonomy=PATH  The path of a TSV file mapping labels onto taxa.
+                        If not specified, use the included default taxonomy:
+                        https://github.com/laowantong/paroxython/blob/0.4.0/paroxython/resources/taxonomy.tsv
+    ```
 """
 
 from pathlib import Path
@@ -36,13 +39,14 @@ from ..make_db import Database
 
 
 def cli_wrapper(args):
+    taxonomy_path = Path(args["--taxonomy"]) if args["--taxonomy"] else None
     db = Database(
         directory=Path(args["DIRECTORY"]),
-        ignore_timestamps=False,
-        cleanup_strategy=args["--cleanup"],
-        exclude_pattern=args["--exclude"],
-        glob_pattern=args["--glob"],
-        taxonomy_path=Path(args["--taxonomy"]) if args["--taxonomy"] else None,
+        ignore_timestamps=args["--no_timestamp"],
+        cleanup_strategy=args["--cleanup"],  # -> list_programs
+        skip_pattern=args["--skip"],  # -> list_programs
+        glob_pattern=args["--glob"],  # -> list_programs
+        taxonomy_path=taxonomy_path,  # -> Taxonomy
     )
     if not args["--output"]:
         db.write_json()
