@@ -1,17 +1,19 @@
-"""
+"""Tag one Python file and output the table of its taxa or labels.
+
 USAGE:
+    ```
     paroxython tag [options] FILENAME
+    ```
 
 OPTIONS:
+    ```plain
     -f --format=FORMAT  Format of the output, either "md" (Markdown)
-                        or "tsv" (Tab SeparatedValues). [default: md]
-    -l --labels         Output the labels instead of the taxons.
-    -t --taxonomy=PATH  The path of a TSV file mapping labels onto taxons.
-                        If not specified, use the included copy of the table
-                        whose last version is at https://bit.ly/2Yu0LqU.
-
-DESCRIPTION:
-    Tag one Python file and output the table of its taxons or labels.
+                        or "tsv" (Tab Separated Values). [default: md]
+    -l --labels         Output the labels instead of the taxa.
+    -t --taxonomy=PATH  The path of a TSV file mapping labels onto taxa.
+                        If not specified, use the included default taxonomy:
+                        https://github.com/laowantong/paroxython/blob/0.4.0/paroxython/resources/taxonomy.tsv
+    ```
 """
 
 from pathlib import Path
@@ -19,7 +21,7 @@ from typing import List, Tuple, Optional
 from typing_extensions import Literal
 
 from ..goodies import couple_to_string
-from ..label_programs import ProgramLabeller
+from ..parse_program import ProgramParser
 from ..list_programs import get_program
 from ..map_taxonomy import Taxonomy
 from ..user_types import Source
@@ -33,8 +35,8 @@ def main(
     taxonomy_path: Optional[Path] = None,
 ) -> str:
     program = get_program(source, relative_path)
-    labeller = ProgramLabeller()
-    labeller.label_program(program)
+    parse = ProgramParser()
+    program.labels[:] = parse(program)
     couples: List[Tuple[str, str]] = [(tags, "Lines")]
     if tags == "Label":
         for (label_name, label_spans) in sorted(program.labels):
@@ -42,12 +44,13 @@ def main(
             couples.append((label_name, s))
     else:
         taxonomy = Taxonomy(taxonomy_path)
-        taxons = taxonomy.to_taxons(program.labels)
-        for (taxon_name, taxon_spans) in sorted(taxons):
+        taxa = taxonomy.to_taxa(program.labels)
+        for (taxon_name, taxon_spans) in sorted(taxa):
             s = ", ".join(map(couple_to_string, sorted(taxon_spans.elements())))
             couples.append((taxon_name, s))
     if output_format == "md":
-        result = [f"| {tag} | {lines} |" for (tag, lines) in couples]
+        result = [f"| `{tag}` | {lines} |" for (tag, lines) in couples]
+        result[0] = result[0].replace("`", "")
         result[1:1] = ["|:--|:--|"]
     else:
         result = [f"{tag}\t{lines}" for (tag, lines) in couples]
