@@ -1,18 +1,18 @@
 """
 Bring together everything relative to the pre-processing of a given source code.
 
-# Cleaning
+## Cleaning
 
 A useful, albeit not essential, step is to cleanse the code of all its algorithmically irrelevant
 features (blank lines, comments, docstrings, etc.). Lots of examples are provided in the `Cleanup`
-class documentation. Be aware that a certain category of comment is preserved at this stage, the
-so-called “manual hints”, presented in the next paragraph.
+class documentation. Be aware that a certain category of comment is intentionally preserved at this
+stage, the so-called “manual hints”, presented in the next paragraph.
 
-# Manual hints
+## Manual hints
 
 On a given source code, the labelling algorithm may sometimes produce false positives or false
-negatives. Moreover, the semantics of some features may be subjective (e.g., `topic:fun`) or beyond
-the capabilities of Paroxython (e.g., deciding the relevance of the `short_circuit` property of a
+negatives. Moreover, the semantics of some features may be subjective (_e.g._, `topic:fun`) or beyond
+the capabilities of Paroxython (_e.g._, deciding the relevance of the `short_circuit` property of a
 boolean condition). In any case, the user has the possibility to manually label certain lines of
 their source code to hint either the presence or absence of a given feature.
 
@@ -21,9 +21,9 @@ The addition of a label is hinted by a comment starting with `# paroxython:`.
 >>> if i < len(s) and s[i] == x: # paroxython: +short_circuit:And
 
 Note that `short_circuit:And` is a label (of the kind defined, but not necessarily included in
-[spec.md](https://github.com/laowantong/paroxython/blob/master/paroxython/resources/spec.md)), and
-not a taxon. It will be later converted into one or more taxons (according to the mapping of
-[taxonomy.tsv](https://github.com/laowantong/paroxython/blob/master/paroxython/resources/taxonomy.tsv)).
+[spec.md](https://repo/paroxython/resources/spec.md)), and
+not a taxon. It will be later converted into one or more taxa (according to the mapping of
+[taxonomy.tsv](https://repo/paroxython/resources/taxonomy.tsv)).
 
 To delete a label, prefix it with a minus symbol. For instance, the following hint requalifies an
 addition into a concatenation:
@@ -31,7 +31,7 @@ addition into a concatenation:
 >>> print(a + b) # paroxython: -addition_operator +concatenation_operator
 
 If a label should span over several lines, it is hinted on the first line with a `...` suffix
-(meaning “to be continued”), and on the last line with a `...` prefix (meaning“continuing”). In the
+(meaning “to be continued”), and on the last line with a `...` prefix (meaning “continuing”). In the
 following example, a label `super_loop` is manually substituted to the calculated label `loop:for`:
 
 >>> for x in s: # paroxython: +super_loop... -loop:for...
@@ -45,11 +45,6 @@ Some tolerances exist for the syntax:
 - `+` can be omitted.
 - `...` (three dots) can be written `…` (HORIZONTAL ELLIPSIS, U+2026).
 - `# paroxython:` is neither space- nor case-sensitive.
-
-# Implementation note
-Several functions or methods declare a compiled and bound regex pattern as an optional argument. It
-is not meant to be provided by the caller. Its default value will be used systematically, with the
-benefit of being evaluated only once.
 """
 
 from collections import defaultdict
@@ -68,8 +63,6 @@ class Cleanup:
     def __init__(self, cleanup_strategy: str):
         """Collection of cleaning static methods to be applied to a source code.
 
-        The constructor selects the desired transformation.
-
         Args:
             cleanup_strategy (str): The name of the transformation. Currently, any other name than
                 `"full"` (corresponding to `full_cleaning()` comes down to the identity function).
@@ -85,14 +78,15 @@ class Cleanup:
     def full_cleaning(source: Source) -> Source:
         r"""Remove as much noise (comments, etc.) as possible in the given source code.
 
-        1. Suppress initial comments.
-        2. Suppress `if __name__ == '__main__'` part.
-        3. Replace tabulations with spaces.
-        4. Normalize Paroxython hint comments.
-        5. Replace docstrings with `pass` statements (most of which being suppressed at the end of the
-        process).
-        6. Suppress empty or blank lines.
-        7. Suppress useless `pass` statements.
+        Description:
+            1. Suppress initial comments.
+            2. Suppress `if __name__ == '__main__'` part.
+            3. Replace tabulations with spaces.
+            4. Normalize Paroxython hint comments.
+            5. Replace docstrings with `pass` statements (most of which being suppressed at the end
+               of the process).
+            6. Suppress empty or blank lines.
+            7. Suppress useless `pass` statements.
 
         Examples:
             - Empty or blank lines are suppressed.
@@ -121,7 +115,7 @@ class Cleanup:
             <div><div style="display: inline-block; width: 49%;; vertical-align: top"><script src="https://gist-it.appspot.com/github.com/laowantong/paroxython/raw/master/tests/test_cleanup_source.py?slice=161:164&footer=0"></script></div> <div style="display: inline-block; width: 49%;; vertical-align: top"><script src="https://gist-it.appspot.com/github.com/laowantong/paroxython/raw/master/tests/test_cleanup_source.py?slice=165:166&footer=0"></script></div></div>
 
             All examples above automatically extracted from
-            [test_cleanup_source.py](https://github.com/laowantong/paroxython/blob/master/tests/test_cleanup_source.py).
+            [test_cleanup_source.py](https://repo/tests/test_cleanup_source.py).
 
         .. warning::
             Useless pass statements are preserved when they are not followed by a line with a same
@@ -132,7 +126,7 @@ class Cleanup:
         (previous_end_row, previous_end_col) = (-1, 0)
         text = str(source)
         text = Cleanup.suppress_first_comments(text)
-        text = Cleanup.suppress_name_equals_main_stuff(text)
+        text = Cleanup.suppress_main_guard(text)
         text = text.replace("\t", "    ")
         lines = iter(text.split("\n"))
         for token_info in generate_tokens(lambda: next(lines) + "\n"):
@@ -160,15 +154,23 @@ class Cleanup:
         return Source(text)
 
     @staticmethod
-    def suppress_first_comments(source: str, sub=regex.compile(r"\A(#.*\n)*").sub) -> str:
-        """Replace all comments placed on the first lines of the source code."""
+    def suppress_first_comments(
+        source: str, sub: Callable = regex.compile(r"\A(#.*\n)*").sub
+    ) -> str:
+        """Replace all comments placed on the first lines of the source code.
+
+        Argument `sub` [not to be explicitly provided.](docs_developer_manual/index.html#default-argument-trick)
+        """
         return sub("", source)
 
     @staticmethod
-    def suppress_name_equals_main_stuff(
+    def suppress_main_guard(
         source: str, sub: Callable = regex.compile(r"(?ms)^if +__name__ *== *.__main__. *:.+").sub
     ) -> str:
-        """Suppress `if __name__ == '__main__'` part."""
+        """Suppress `if __name__ == '__main__'` part.
+
+        Argument `sub` [not to be explicitly provided.](docs_developer_manual/index.html#default-argument-trick)
+        """
         return sub("", source)
 
     @staticmethod
@@ -183,19 +185,27 @@ class Cleanup:
 
         For instance, if `HINT_COMMENT` is `"# paroxython:"` (its default value), the actual search
         pattern will be `r"(?i)#\s*paroxython\s*:\s*"`.
+
+        Argument `subn` [not to be explicitly provided.](docs_developer_manual/index.html#default-argument-trick)
         """
         return subn(f"{HINT_COMMENT} ", source)
 
     @staticmethod
     def suppress_blank_lines(source: str, sub: Callable = regex.compile(r"\s*\n").sub) -> str:
-        """Suppress all empty or blank lines in the given source."""
+        """Suppress all empty or blank lines in the given source.
+
+        Argument `sub` [not to be explicitly provided.](docs_developer_manual/index.html#default-argument-trick)
+        """
         return sub("\n", source)
 
     @staticmethod
     def suppress_useless_pass_statements(
         source: str, sub: Callable = regex.compile(r"(?m)^( *)pass\n\1(?!\s)").sub,
     ) -> str:
-        """Suppress all `pass` statements followed by a line with a same level of indentation."""
+        """Suppress all `pass` statements followed by a line with a same level of indentation.
+
+        Argument `sub` [not to be explicitly provided.](docs_developer_manual/index.html#default-argument-trick)
+        """
         return sub(r"\1", source)
 
 
@@ -204,9 +214,10 @@ def centrifugate_hints(
 ) -> Source:
     """Transform the isolated hints into all-encompassing hints.
 
-    When a hint is isolated on its own line, it is considered to extend to the entire program.
-    These hints are moved to both ends of the source (centrifugated), and made open on the first
-    line and close on the last line.
+    Description:
+        When a hint is isolated on its own line, it is considered to extend to the entire program.
+        These hints are moved to both ends of the source (centrifugated), and made open on the
+        first line and close on the last line.
 
     Examples:
         - Some isolated hints (`hint_3` and `hint_5` are centrifugated).
@@ -217,7 +228,9 @@ def centrifugate_hints(
         <div><div style="display: inline-block; width: 49%;; vertical-align: top"><script src="https://gist-it.appspot.com/github.com/laowantong/paroxython/raw/master/tests/test_centrifugate_hints.py?slice=42:47&footer=0"></script></div> <div style="display: inline-block; width: 49%;; vertical-align: top"><script src="https://gist-it.appspot.com/github.com/laowantong/paroxython/raw/master/tests/test_centrifugate_hints.py?slice=48:53&footer=0"></script></div></div>
 
         All examples above automatically extracted from
-        [test_centrifugate_hints.py](https://github.com/laowantong/paroxython/blob/master/tests/test_centrifugate_hints.py).
+        [test_centrifugate_hints.py](https://repo/tests/test_centrifugate_hints.py).
+
+        Argument `match_isolated_hints` [not to be explicitly provided.](docs_developer_manual/index.html#default-argument-trick)
     """
     lines = []
     hints: Set[str] = set()
@@ -277,14 +290,15 @@ def collect_hints(
 ) -> Tuple[LabelsSpans, LabelsSpans]:
     """Schedule for addition or deletion the hints appearing in the comments.
 
-    On this stage, the source code is scanned for manual hints. They are set aside in two separate
-    containers (depending on whether the user intends to add or remove them). They will later be
-    used to tweak the labelling results obtained by static analysis.
+    Description:
+        On this stage, the source code is scanned for manual hints. They are set aside in two
+        separate containers (depending on whether the user intends to add or remove them). They
+        will later be used to tweak the labelling results obtained by static analysis.
 
     Args:
-        source (Source): [description]
+        source (Source): A source code.
         match_label (Callable, optional): A function matching a label composed of alphanumeric
-            characters and colons.
+            characters and colons. [Not to be explicitly provided.](docs_developer_manual/index.html#default-argument-trick)
 
     Raises:
         ValueError: Raised in various cases of malformed input.
@@ -349,5 +363,8 @@ def collect_hints(
 def remove_hints(
     source: Source, sub_hints: Callable = regex.compile(fr"\s*{HINT_COMMENT} .*").sub,
 ) -> Source:
-    """Once they are collected, remove all Paroxython hints from the given source."""
+    """Once they are collected, remove all Paroxython hints from the given source.
+
+    Argument `sub_hints` [not to be explicitly provided.](docs_developer_manual/index.html#default-argument-trick)
+    """
     return Source(sub_hints("", source).strip())
